# T-SHIELD regularization

T-SHIELD (Transformation-Selective Hidden Input Evaluation for Learning Dynamics) is a regularization
technique that aims to enhance model interpretability while improves model performance. Specifically, T-SHIELD adds a regularization term to the objective function that penalizes if it relies too heavily on
a small subset of input features.

You can find the documentation of the package [here](https://tshield-xai.readthedocs.io/en/latest/).

If you use this code or find it useful, please cite our paper:

```

@article{sevillano2024shield,
  title={SHIELD: A regularization technique for eXplainable Artificial Intelligence},
  author={Sevillano-Garc{\'\i}a, Iv{\'a}n and Luengo, Juli{\'a}n and Herrera, Francisco},
  journal={arXiv preprint arXiv:2404.02611},
  year={2024}
}

```

## Installation

You can install this package by simply use pip:

```bash
pip install tshield-xai
```
